<?php
require_once(dirname(__FILE__).DIRECTORY_SEPARATOR.'SprypayException.php');
/**
 * Генерирует форму для запроса платежа.
 * 
 * @package Sprypaylib
 * @version $id$
 * @copyright 2012 by Sprypay {@link http://sprypay.ru}
 * @license BSD
 */
class SprypayRequestPaymentForm
{
    private $formData = array();
    private $formId = 'sprypayForm';
    private $formMethod = 'post';
    private $formAction = 'https://sprypay.ru/sppi/';
    private $submitLabel = 'submit';
    private $autoSubmit = true;

    /**
     * Устанавливает идентификатор магазина в Sprypay через который совершается платеж.
     * 
     * @param int $shopId 
     * @access public
     * @return void
     */
    public function setShopId($shopId)
    {
        $this->formData['spShopId'] = $shopId;
    }

    /**
     * Устанавливает идентификатор покупки.
     * 
     * @param mixed $shopPaymentId 
     * @access public
     * @return void
     */
    public function setShopPaymentId($shopPaymentId)
    {
        $this->formData['spShopPaymentId'] = $shopPaymentId;
    }

    /**
     * Устанавливает сумму платежа. 
     * 
     * @param float $amount 
     * @access public
     * @return void
     */
    public function setAmount($amount)
    {
        $this->formData['spAmount'] = $amount;
    }

    /**
     * Устанавливает код валюты платежа.
     * 
     * @param string $currency код валюты в формате ISO
     * @access public
     * @return void
     */
    public function setCurrency($currency)
    {
        $this->formData['spCurrency'] = strtolower($currency);
    }

    /**
     * Устанавливает назначение платежа.
     * 
     * @param string $purpose 
     * @access public
     * @return void
     */
    public function setPurpose($purpose)
    {
        $this->formData['spPurpose'] = $purpose;
    }

    /**
     * Устанавливает email пользователя осуществляющего платеж.
     * 
     * @param string $userEmail 
     * @access public
     * @return void
     */
    public function setUserEmail($userEmail)
    {
        $this->formData['spUserEmail'] = $userEmail;
    }

    /**
     * Устаналивает дополнительные данные от магазина.
     * 
     * @param array $userData
     * @access public
     * @return void
     */
    public function setUserData(array $userData)
    {
        foreach ($userData as $name => $value)
            $this->formData['spUserData'.$name] = $value;
    }

    /**
     * Устанавливает язык для покупателя.
     * 
     * @param string $language код языка в формате ISO
     * @access public
     * @return void
     */
    public function setLanguage($language)
    {
        $this->formData['lang'] = $language;
    }

    /**
     * Устанавливает URL на который будет перенаправлен пользователь в случае удачного выполнения платежа.
     * 
     * @param string $successUrl 
     * @access public
     * @return void
     */
    public function setSuccessUrl($successUrl)
    {
        $this->formData['spSuccessUrl'] = $successUrl;
    }

    public function setSuccessMethod($successMethod)
    {
        if ($successMethod == 'post')
            $this->formData['spSuccessMethod'] = 1;
        elseif ($successMethod == 'get')
            $this->formData['spSuccessMethod'] = 0;
        else
            throw new SprypayException('Unknown success method '.$successMethod);
    }

    /**
     * Устанавливает URL на который будет перенаправлен пользователь в случае неудачного выполнения платежа.
     * 
     * @param string $failUrl 
     * @access public
     * @return void
     */
    public function setFailUrl($failUrl)
    {
        $this->formData['spFailUrl'] = $failUrl;
    }

    public function setFailMethod($failMethod)
    {
        if ($failMethod == 'post')
            $this->formData['spFailMethod'] = 1;
        elseif ($failMethod == 'get')
            $this->formData['spFailMethod'] = 0;
        else
            throw new SprypayException('Unknown fail method '.$failMethod);
    }

    /**
     * Устанавливает URL для оповещения о платеже.
     * 
     * @param mixed $ipnUrl 
     * @access public
     * @return void
     */
    public function setIpnUrl($ipnUrl)
    {
        $this->formData['spIpnUrl'] = $ipnUrl;
    }

    /**
     * Устанавливает метод при помощи которого будет осуществляться оповещение о платеже.
     * 
     * @param string $ipnMethod "get" | "post"
     * @access public
     * @return void
     */
    public function setIpnMethod($ipnMethod)
    {
        if ($ipnMethod == 'post')
            $this->formData['spIpnMethod'] = 1;
        elseif ($ipnMethod == 'get')
            $this->formData['spIpnMethod'] = 0;
        else
            throw new SprypayException('Unknown ipn method '.$ipnMethod);
    }

    /**
     * Устанавливает платежные системы разрещенные для приема.
     * 
     * @param array $allowedPaymentSystems
     * @access public
     * @return void
     */
    public function setAllowedPaymentSystems(array $allowedPaymentSystems)
    {
        $this->formData['spSelectedPS'] = implode(',', $allowedPaymentSystems);
    }

    /**
     * Устанавливает платежные системы запрещенные для приема.
     * 
     * @param array $forbiddenPaymentSystems 
     * @access public
     * @return void
     */
    public function setForbiddenPaymentSystems(array $forbiddenPaymentSystems)
    {
        $this->formData['spForbiddenPS'] = implode(',', $forbiddenPaymentSystems);
    }

    /**
     * Устанавливает того кто будет платить комиссию системы.
     * 
     * @param string $feePayer "seller" | "buyer"
     * @access public
     * @return void
     */
    public function setFeePayer($feePayer)
    {
        if ($feePayer == 'buyer')
            $this->formData['spFeePayer'] = 0;
        elseif ($feePayer == 'seller') 
            $this->formData['spFeePayer'] = 1;
        else
            throw new SprypayException('Unknown fee payer '.$feePayer);
    }

    /**
     * Устанавливает метод отправки данных для формы запроса платежа.
     * 
     * @param string $method 
     * @access public
     * @return void
     */
    public function setMethod($method)
    {
        if ($method == 'get' || $method == 'post')
            $this->formMethod = $method;
        else
            throw new SprypayException('Unknown request method '.$method);
    }

    /**
     * Устанавливает текст кнопки для подтверждения формы.
     * 
     * @param string $label 
     * @access public
     * @return void
     */
    public function setSubmitLabel($label)
    {
        $this->submitLabel = $label;
    }

    /**
     * Включает автоматическое подтверждение формы запроса платежа.
     * 
     * @access public
     * @return void
     */
    public function enableAutoSubmit()
    {
        $this->autoSubmit = true;
    }

    /**
     * Отключает автоматическое подтверждения формы.
     * 
     * @access public
     * @return void
     */
    public function disableAutoSubmit()
    {
        $this->autoSubmit = false;
    }

    /**
     * Возвращает код формы запроса платежа.
     * 
     * @access public
     * @return string
     */
    public function renderForm()
    {
        $form  = '<form id ="'.$this->formId.'" action="'.$this->formAction.'" method="'.$this->formMethod.'">';
        foreach ($this->formData as $name => $value)
            $form .= $this->renderInputField($name, $value);
        $form .= '<input type="submit" value="'.$this->submitLabel.'"/>';
        $form .= '</form>';
        if ($this->autoSubmit)
            $form .= '<script type="text/javascript"> document.forms["'.$this->formId.'"].submit(); </script>';
        return $form;
    }

    private function renderInputField($name, $value)
    {
        return '<input type="hidden" name="'.$name.'" value="'.$value.'" />';
    }
}
?>
